]> git.sesse.net Git - cubemap/blobdiff - input.h
Use nullptr instead of NULL everywhere.
[cubemap] / input.h
diff --git a/input.h b/input.h
index 1b94e59ffef5faf1b8952e797caa62653f337af8..7e67392da0319fc50ac2dbe254495c0a919614d2 100644 (file)
--- a/input.h
+++ b/input.h
@@ -21,14 +21,20 @@ struct InputStats {
 
        // The number of data bytes we have received so far (or more precisely,
        // number of data bytes we have sent on to the stream). This excludes Metacube
// headers and corrupted data we've skipped.
        //
        // Not reset across connections.
        size_t data_bytes_received;
 
+       // Same, except counts only Metacube metadata.
+       size_t metadata_bytes_received;
+
        // When the current connection was initiated. -1 if we are not currently connected.
        time_t connect_time;
 
+       // Last latency measurement, HUGE_VAL if no measurement yet.
+       double latency_sec;
+
        // TODO: Number of loss events might both be useful,
        // similar to for clients. Also, per-connection byte counters.
 };
@@ -52,7 +58,7 @@ public:
 bool parse_url(const std::string &url, std::string *protocol, std::string *user, std::string *host, std::string *port, std::string *path);
 
 // Figure out the right type of input based on the URL, and create a new Input of the right type.
-// Will return NULL if unknown.
+// Will return nullptr if unknown.
 Input *create_input(const std::string &url, Input::Encoding encoding);
 Input *create_input(const InputProto &serialized);
@@ -21,14 +21,20 @@ struct InputStats {
        // The number of data bytes we have received so far (or more precisely,
        // number of data bytes we have sent on to the stream). This excludes Metacube
-       // headers and corrupted data we've skipped.
+       // headers, metadata and corrupted data we've skipped.
        //
        // Not reset across connections.